// Aggregates all former standalone integration tests as modules.
mod add_dir;
mod apply_patch;
mod auth_env;
mod ephemeral;
mod mcp_required_exit;
mod originator;
mod output_schema;
mod resume;
mod sandbox;
mod server_error_exit;
